@@ -29,7 +29,7 @@ def cmd(ctx, url, key, secret, export_format, **kwargs):
     client = ctx.obj.start_client(url=url, key=key, secret=secret)
 
     with ctx.obj.exc_wrap(wraperror=ctx.obj.wraperror):
-        data = client.system.meta.about()
+        data = client.meta.about()
 
     if export_format == "json":
         click.secho(json_dump(data))
