@@ -3,7 +3,14 @@
 import click
 
 from ..context import AliasedGroup
-from . import cmd_convert_cert, cmd_shell, cmd_signup, cmd_sysinfo, cmd_write_config
+from . import (
+    cmd_convert_cert,
+    cmd_shell,
+    cmd_signup,
+    cmd_sysinfo,
+    cmd_use_token_reset_token,
+    cmd_write_config,
+)
 
 
 @click.group(cls=AliasedGroup)
@@ -16,3 +23,4 @@ tools.add_command(cmd_write_config.cmd)
 tools.add_command(cmd_sysinfo.cmd)
 tools.add_command(cmd_signup.cmd)
 tools.add_command(cmd_convert_cert.cmd)
+tools.add_command(cmd_use_token_reset_token.cmd)
