@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Test suite for axonius_api_client.tools."""
 from ....cli import cli
-from ....constants import CSV_ADAPTER, DEFAULT_NODE
+from ....constants.adapters import CSV_ADAPTER
 from ....tools import json_load
 from ...utils import load_clirunner
 
@@ -14,8 +14,6 @@ class TestGrpCnxCmdGet:
             "adapters",
             "cnx",
             "get",
-            "--node-name",
-            DEFAULT_NODE,
             "--name",
             CSV_ADAPTER,
             "--export-format",
@@ -41,8 +39,6 @@ class TestGrpCnxCmdGet:
             "adapters",
             "cnx",
             "get",
-            "--node-name",
-            DEFAULT_NODE,
             "--name",
             CSV_ADAPTER,
             "--export-format",
@@ -68,8 +64,6 @@ class TestGrpCnxCmdGet:
             "adapters",
             "cnx",
             "get",
-            "--node-name",
-            DEFAULT_NODE,
             "--name",
             CSV_ADAPTER,
             "--export-format",
@@ -95,8 +89,6 @@ class TestGrpCnxCmdGet:
             "adapters",
             "cnx",
             "get",
-            "--node-name",
-            DEFAULT_NODE,
             "--name",
             CSV_ADAPTER,
             "--export-format",
@@ -120,8 +112,6 @@ class TestGrpCnxCmdGet:
             "adapters",
             "cnx",
             "get",
-            "--node-name",
-            DEFAULT_NODE,
             "--name",
             CSV_ADAPTER,
             "--export-format",
@@ -145,8 +135,6 @@ class TestGrpCnxCmdGet:
             "adapters",
             "cnx",
             "get",
-            "--node-name",
-            DEFAULT_NODE,
             "--name",
             CSV_ADAPTER,
             "--export-format",
@@ -170,8 +158,6 @@ class TestGrpCnxCmdGet:
             "adapters",
             "cnx",
             "get",
-            "--node-name",
-            DEFAULT_NODE,
             "--name",
             CSV_ADAPTER,
             "--export-format",
